=========================
BG Coord Table File Utils
=========================
Collection of Python modules for reading and writing the gene-exons coordinate table file.



Features
--------

* CoordTableFileParser class for reading the gene-exons coordinate table file
* CoordTableFileWriter class for writing the gene-exons coordinate table file
* CoordTableRecord class for representing the gene-exons coordinate table record

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
